<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;
use App\Models\User;
use App\Models\Produit;

class HomeController extends Controller
{
    /**
     * Create a new controller instance.
     *
     * @return void
     */
    public function __construct()
    {
        $this->middleware('auth');
    }

    /**
     * Show the application dashboard.
     *
     * @return \Illuminate\Contracts\Support\Renderable
     */
    public function index()
    {
        $products = Produit::all()->count();
        $users = User::all()->count();
        return view('components._dashboard')->with('products', $products)->with('users', $users);
    }
    public function listMoral()
    {
        $morales = User::where('status', 'morale')->get();
        return view('components._listMoral')->with('morales', $morales);
    }
    public function listPhysic()
    {
        $physiques = User::where('status', 'physique')->get();
        return view('components._listPhysic')->with('physiques', $physiques);
    }
    public function listProduit()
    {
        $produits = Produit::all();
        return view('components._listProduit')->with('produits', $produits);
    }
    public function listCommande()
    {
        return view('components._listCommande');
    }
    public function listLivraison()
    {
        return view('components._listLivraison');
    }
    public function produit()
    {
        return view('components.newProduit');
    }
    public function entreeStock()
    {
        $produits = Produit::all();
        return view('components._entreeStock')->with('produits', $produits);
    }

    public function newProduit(Request $request)
    {
        $produit = new Produit;
        $produit->nomProduit = $request->nomProduit;
        $produit->categorieProduit = $request->categorieProduit;
        $produit->quantiteProduit = $request->quantiteProduit;
        $produit->seuil = $request->seuil;
        $produit->prixGrossiste = $request->prixGrossiste;
        $produit->prixDetaillant = $request->prixDetaillant;
        $produit->prixDistributeur = $request->prixDistributeur;
        $produit->datePeremption = $request->datePeremption;
        $query = $produit->save();
        if($query){
            $success = "Le produit ". $produit->nomProduit ." a été bien ajouté";
            return redirect()->back()->with('success', $success);
        
        }
        else{
            $error = "Une erreur est survenue";
            return redirect()->back()->with('error', $error);
        }

    }
    public function entreeStockProduit(Request $request){
        $id = $request->idProduit;
        $quantite = $request->quantiteProduit;

        $produit = Produit::find($id);
        $produit->quantiteProduit +=$quantite;
        $requete = $produit->save();
        if($requete){
            $success = "Le produit ". $produit->nomProduit ." a été bien mis à jour";
            return redirect()->back()->with('success', $success);
        
        }
        else{
            $error = "Une erreur est survenue";
            return redirect()->back()->with('error', $error);
        }
    }
    public function profile()
    {
        return view('components._profile');
    }

    public function profileMoral()
    {
        return view('components._profileMoral');
    }

    public function modifyProduit($id)
    {
        $produit = Produit::where('id', $id)->get()->first();
        return view('components.__modifyProduit')->with('produit', $produit);
    } 

    public function removeProduit($id)
    {
        $produit = Produit::where('id', $id)->get()->first();
        return view('components.__removeProduit')->with('produit', $produit);
    } 


    public function modify($id, Request $request)
    {
        $produit = Produit::where('id', $id)->get()->first();
        $produit->nomProduit = $request->nomProduit;
        $produit->categorieProduit = $request->categorieProduit;
        $produit->quantiteProduit = $request->quantiteProduit;
        $produit->seuil = $request->seuil;
        $produit->prixGrossiste = $request->prixGrossiste;
        $produit->prixDetaillant = $request->prixDetaillant;
        $produit->prixDistributeur = $request->prixDistributeur;
        $produit->datePeremption = $request->datePeremption;
        
        $query = $produit->save();
        if($query){
            $success = "Le produit ". $produit->nomProduit ." a été bien modifié";
            return redirect()->back()->with('success', $success);
        
        }
        else{
            $error = "Une erreur est survenue";
            return redirect()->back()->with('error', $error);
        }
    } 

    public function remove($id, Request $request){
        $produit = Produit::where('id', $id)->get()->first();
        $query = $produit->delete();
        if($query){
            $success = "Le produit ". $produit->nomProduit ." a été bien supprimé";
            return redirect()->route('listProduit')->with('success', $success);
        }
        else{
            $error = "Une erreur est survenue";
            return redirect()->route('listProduit')->with('error', $error);
        }
    }

    /*public function deleteProduit(Request $request)
    {
        $id = (int) $request->data;
        $produit = Produit::where('id', $id)->get()->first();;
        dd($produit);
        $produit->delete();
        return redirect()->route('produit');
    }*/
}
